@@ -1,7 +1,6 @@
 package Authorization::RBAC;
-$Authorization::RBAC::VERSION = '0.08';
+$Authorization::RBAC::VERSION = '0.09';
 use utf8;
-use v5.10;
 use Moose;
 with 'MooseX::Object::Pluggable';
 
@@ -158,7 +157,7 @@ sub check_permission {
       $self->_log("- Search if role " . $r->name ." can '" . $op->name . "' '${typeobj}_" . $obj->id."'");
 
       # get permission from backend
-      my ($result, $apply_to_children) = $self->get_permission($r, $op, $obj);
+      my ($result, $inheritable) = $self->get_permission($r, $op, $obj);
 
       if ( ! defined $result ) {
         next;
@@ -199,7 +198,7 @@ Authorization::RBAC - Role-Based Access Control system
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -257,7 +256,7 @@ my $access = $rbac->can_access($roles, $objet, $additional_operations );
 
 Un Objet peut avoir une méthode 'parent'. Si c'est le cas alors 2 mécanismes s'ajoute au système de permission :
 
-- L'accès à un objet est obtenu si l'accès est permis à tous ses parents. Par exemple, pour accéder à la Page '/admin/user/add', le(s) devra successivement accéder à '/', 'admin', 'user' et enfin 'add'.
+- L'accès à un objet est obtenu si l'accès est permit à tous ses parents. Par exemple, pour accéder à la Page '/admin/user/add', le(s) role(s) devra successivement accéder à '/', 'admin', 'user' et enfin 'add'.
 
 - En second lieu une Permission peut être rechercher récursivement sur les parents de l'Objet.
 
@@ -272,7 +271,7 @@ Page:
     ops_to_access: create_Page
 
 Pour accéder à l'Objet 'Page /admin/user/add', le(s) role(s) devra posséder des Permissions répondant à 'view_Page sur Page /', 'view_Page sur Page admin' et 'create_Page sur Page add'.
-Imaginons que le(s) role(s) ne peuvent accèder à l'Objet. Par exemple si le(s) role(s) ne peuvent accéder à 'create_Page sur Page add' alors la recherche de la Permission se fera aussi sur 'admin' puis sur '/'. Pour que cette règle s'applique il faut que la Permission ait une méthode 'apply_to_children' qui si elle retourne 1 rendra la Permission héritable par ses enfants. Si elle retourne cela a l'effet inverse, ça signifie que le role n'a pas ou plus cette Permission.
+Imaginons que le(s) role(s) ne peut accèder à l'Objet. Par exemple si le(s) role(s) ne possède pas la Permission 'create_Page sur Page add' alors la recherche de la Permission se fera aussi sur 'admin' puis sur '/'. Pour que cette règle s'applique il faut que la Permission ait une méthode 'inheritable' qui si elle retourne 1 rendra la Permission héritable par ses enfants. Si elle retourne 0 cela a l'effet inverse, ça signifie que le role n'a pas ou plus cette Permission.
 
 Imaginons maintenant que les roles aient les Permissions suivantes :
 
@@ -280,21 +279,23 @@ Roles:
   administrateur:
     view_Page:
       Page_/: 1
-       apply_to_children: 1
+       inheritable: 1
       Page_admin: 1
-       apply_to_children: 1
+       inheritable: 1
     create_Page:
       Page_/: 1
-       apply_to_children: 1
+       inheritable: 1
   anonymous:
     view_Page:
       Page_/; 1
-       apply_to_children: 1
+       inheritable: 1
       Page_admin: 0
-       apply_to_children: 1
+       inheritable: 1
 
 
-Ainsi lorsque l'on recherche si le role 'administrateur' peut accéder à / admin / user / add, on ne trouvera pas de Permission 'create_Page sur Page add' mais on la retrouvera sur le parent racine et cette Permission est 'apply_to_children:' donc heritable.
+Ainsi lorsque l'on recherche si le role 'administrateur' peut accéder à / admin / user / add, on ne trouvera pas de Permission 'create_Page sur Page add' mais on la retrouvera sur le parent racine et cette Permission est héritable.
+
+Attention car nous avons donné la Permission 'view_Page sur Page / héritable' à 'anonymous' donc si rien n'est fait il a aussi accès à /admin. C'est pourquoi Nous lui avons aussi donné la Permission 'Ne peut view_Page sur Page_Admin héritable'. Ainsi l'accès à /admin est bloqué.
 
 
 
