@@ -1,5 +1,5 @@
 package Authorization::RBAC::Backend::DBIx;
-$Authorization::RBAC::Backend::DBIx::VERSION = '0.08';
+$Authorization::RBAC::Backend::DBIx::VERSION = '0.09';
 use Moose::Role;
 use base 'DBIx::Class::Schema';
 use Carp qw/croak/;
@@ -85,7 +85,7 @@ sub get_permission{
   my $parent_field = $self->config->{typeobj}->{$typeobj}->{parent_field} || 'parent';
 
   if ( $permission ) {
-    return ($permission->value, $permission->apply_to_children);
+    return ($permission->value, $permission->inheritable);
   }
   # Search permission on parents
   elsif ( $obj->can( $parent_field) ) {
@@ -95,9 +95,9 @@ sub get_permission{
       my $typeobj_parent    = ref($obj->$parent_field);
       $typeobj_parent =~ s/.*:://;
       $self->_log("  [??] Search inherited permissions on parents ${typeobj_parent}_" . $obj->$parent_field->id . "...");
-      my ( $result, $apply_to_children)  = $self->get_permission($role, $op, $obj->$parent_field);
-      if ( $apply_to_children || ! $result  ) {
-        return ($result, $apply_to_children);
+      my ( $result, $inheritable)  = $self->get_permission($role, $op, $obj->$parent_field);
+      if ( $inheritable || ! $result  ) {
+        return ($result, $inheritable);
       }
     }
   }
@@ -178,7 +178,7 @@ Authorization::RBAC::Backend::DBIx - Backend 'DBIx' for Authorization::RBAC
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 CONFIGURATION
 
