@@ -7,10 +7,10 @@ Schema::TPath::Result::Comment
 
 =cut
 
-use Moose;
-use MooseX::NonMoose;
-use MooseX::MarkAsMethods autoclean => 1;
-extends 'DBIx::Class::Core';
+use strict;
+use warnings;
+
+use base 'DBIx::Class::Core';
 
 
 __PACKAGE__->load_components;
